@@ -443,11 +443,12 @@ class Organization(Auth):
 
 class Customers(Auth):
 
-    def get_customer_by_phone(self, params: dict = None) -> dict:
+    def get_customer_by_phone(self, params: dict = None, timeout = 5) -> dict:
         """
         Получить данные гостя по его номеру телефона
 
         :param params: {"phone" : "+79999999999",} телефон пользователя
+        :param timeout: timeout for request in second (5 or 5.05)
         :return: OrganizationGuestInfo Данные гостя (включая баланс)
         """
         # /api/0/customers/get_customer_by_phone?access_token={accessToken}&organization={organization}&phone={userPhone}
@@ -459,19 +460,20 @@ class Customers(Auth):
         try:
             result = self.session_s.get(
                 f'{self.base_url}/api/0/customers/get_customer_by_phone?access_token={self.token}'
-                f'&organization={self.org}', params=params)
+                f'&organization={self.org}', params=params, timeout=timeout)
             return result.json()
         except requests.exceptions.RequestException as err:
             raise GetException(self.__class__.__qualname__,
                                self.get_customer_by_phone.__name__,
                                f"[ERROR] Не удалось получить данные гостя по его номеру телефона: \n{err}")
 
-    def get_customer_by_id(self, params: dict = None) -> dict:
+    def get_customer_by_id(self, params: dict = None, timeout = 5) -> dict:
         """
         Получить данные гостя по его идентификатору
         Получить информацию о госте организации по его уникальному идентификатору.
 
         :param params: {"id": "userId"} Идентификатор гостя
+        :param timeout: timeout for request in second (5 or 5.05)
         :return: OrganizationGuestInfo Данные гостя (включая баланс)
         """
         # /api/0/customers/get_customer_by_id?access_token={accessToken}&organization={organization}&id={userId}
@@ -483,19 +485,20 @@ class Customers(Auth):
         try:
             result = self.session_s.get(
                 f'{self.base_url}/api/0/customers/get_customer_by_id?access_token={self.token}&organization={self.org}',
-                params=params)
+                params=params, timeout=timeout)
             return result.json()
         except requests.exceptions.RequestException as err:
             raise GetException(self.__class__.__qualname__,
                                self.get_customer_by_id.__name__,
                                f"[ERROR] Не удалось получить данные гостя по его идентификатору: \n{err}")
 
-    def get_customer_by_card(self, params: dict = None) -> dict:
+    def get_customer_by_card(self, params: dict = None, timeout = 5) -> dict:
         """
         Получить данные гостя организации по его номеру карты
         Получить информацию о госте организации по его номеру карты внутри организации.
 
         :param params: {"card": "cardNumber"} Номер карты гостя
+        :param timeout: timeout for request in second (5 or 5.05)
         :return: OrganizationGuestInfo Данные гостя (включая баланс)
         """
         # /api/0/customers/get_customer_by_card?access_token={accessToken}&organization={organization}&card={cardNumber}
@@ -507,14 +510,14 @@ class Customers(Auth):
         try:
             result = self.session_s.get(
                 f'{self.base_url}/api/0/customers/get_customer_by_card?access_token={self.token}'
-                f'&organization={self.org}', params=params)
+                f'&organization={self.org}', params=params, timeout=timeout)
             return result.json()
         except requests.exceptions.RequestException as err:
             raise GetException(self.__class__.__qualname__,
                                self.get_customer_by_card.__name__,
                                f"[ERROR] Не удалось получить данные гостя по его номеру карты: \n{err}")
 
-    def create_or_update(self, customer_for_import: dict = None) -> dict:
+    def create_or_update(self, customer_for_import: dict = None, timeout=15) -> dict:
         """
         Создать гостя или обновить информацию о госте
         Метод создает гостя, если заданного телефона нет в базе или обновляет информацию о
@@ -523,6 +526,7 @@ class Customers(Auth):
         в запросе на обновление, то метод не изменяет значение данного поля у гостя
 
         :param customer_for_import: CustomerForImport Данные пользователя (здесь поле id является обязательным)
+        :param timeout: timeout for request in second
         :return: Идентификатор гостя
         """
         # /api/0/customers/create_or_update?access_token={accessToken}&organization={organizationId}
@@ -534,7 +538,7 @@ class Customers(Auth):
         try:
             result = self.session_s.post(
                 f'{self.base_url}/api/0/customers/create_or_update?access_token={self.token}&organization={self.org}',
-                json=customer_for_import, )
+                json=customer_for_import,timeout=timeout )
             return result.json()
         except requests.exceptions.RequestException as err:
             raise PostException(self.__class__.__qualname__,
@@ -553,7 +557,7 @@ class Customers(Auth):
         # /api/0/customers/{customerId}/add_category?access_token={accessToken}&organization={organizationId}&categoryId={categoryId}
         if customer_id is None or category_id is None:
             raise ParamSetException(self.__class__.__qualname__,
-                                    self.create_or_update.__name__,
+                                    self.add_category.__name__,
                                     f"[ERROR] Не присвоен обязательный параметр: "
                                     f"\"customer_id\" или \"category_id\"")
         self.check_token_time()
